==> dwarfg_install_1.9.0.tgz: dwarfg_install/appdir/db_init_verdata.sql <==
INSERT INTO agents (name, dir_name, package_name, minimal_version, dev_type, show_in_shortcut, description) VALUES
('Advantech routers', 'agent_advantech', 'adwarfg_advantech.tgz', '6.2.0', 2, true, 'Supports V2, V2i, V3 and V4 running ConelOS/ICR OS'),
("Teltonika routers - monitoring+FW flash", 'agent_teltonika', 'adwarfg_teltonika.ipk', NULL, 4, true, 'Monitoring only functionality, server certificate check is disabled.'),
("OpenWRT - only monitoring", 'agent_owrt', 'adwarfg_owrt.ipk', NULL, 3, true, 'Needs installing openssh-client for tunnels on the OpenWRT system, otherwise monitoring-only. Server certificate check is disabled.'),
('GNU/Linux (generic)', 'agent_linux', 'adwarfg_linux.tgz', NULL, 1, true, 'Generic Linux agent with systemd/initd integration. Cmdline installation.'),
("Teltonika routers - cmdline, monitoring+FW flash", 'agent_teltonika', 'adwarfg_teltonika.tgz', NULL, 4, false, 'Cmdline install. Needs installing openssh-client for tunnels on the Teltonika system. Server certificate check is disabled.'),
("OpenWRT - cmdline, mon. only", 'agent_owrt', 'adwarfg_owrt.tgz', NULL, 3, false, 'Cmdline install. Needs installing openssh-client for tunnels on the OpenWRT system. Server certificate check is disabled.'),
("AAD - automated agent deployment tool", 'aad', 'push_agent.py', NULL, 1, false, 'A command-line level Python tool to automate mass device installation. See documentation before experimenting.');

INSERT INTO agent_device_type_map (agent_id, device_type_id) VALUES (1, 2), (2, 1), (3, 3), (4, 4), (1, 5);

INSERT INTO agent_versions (dev_type, version_major, version_minor, version_patchlevel, actual) VALUES
(1, 1, 9, 0, true),
(2, 1, 9, 0, true),
(3, 1, 9, 0, true),
(4, 1, 9, 0, true);

INSERT INTO product_versions (id, actual, version_major, version_minor, version_patchlevel, version_string, major, beta, notification, force_display, release_date, description) values 
(1, true, 1, 9, 0, 'Keeper RC1', false, true, true, true, '2026-02-28',
'<h5>Release notes</h5>'
'<ul>'
'<li>Release Notes for version 2.0.0 follows (copied into RC1).</li>'
'</ul>'
'<h6>Server:</h6><ul>'
'<li>Support for manual upload of firmware files by user + logging for this action.</li>'
'<li>Support firmware management for Teltonika devices (running RUTOS).</li>'
'<li>Customizable and centrally managed configuration profiles for Advantech routers.</li>'
'<li>Initial support for CS-Tech devices (includes firmware management for CS-Tech Linux).</li>'
'<li>Introduced SNMP Gateway to allow monitoring of SNMP devices (aimed at Advantech v1 routers but concept works for any SNMP device).</li>'
'<li>Implemented SSH tunnels via web gateway and proxy.</li>'
'<li>Customizable culumn names for Note1 .. Note3 columns (for administrator via commandline - see customize_columnnames.sh script).</li>'
'<li>Support model name (device model) and added it as optional column on the Devices table allowing filtering+sorting based on that.</li>'
'<li>Improved Dwarfguard command-line integaration:</li>'
'<ul><li>Implemented non-interactive mode so that the commands could be used in scripting.</li>'
'<li>Added dwarfg_user command allowing server admin to add new UI users.</li>'
'<li>Added dwarfg_home and dwarfg_servdata commands to enter the deployment base directory/runtime data directory or just show the location when running non-interactively.</li>'
'<li>Added dwarfg_pyvenv command to enter the deployment base directory/show the location.</li></ul>'
'<li>Header line and detail/actions columns in the Devices table are now anchored.</li>'
'<li>Added SignalQuality as an optional column for the Devices table.</li>'
'<li>Implemented automated partial upgrade from version 1.0.6.</li>'
'<li>Fixed Signal CSQ and RSSI DB data in Device Details and Devices table.</li>'
'<li>Automated DB view rebuild on upgrade.</li>'
'<li>Added Note1,2,3 fields to the Device details.</li>'
'<li>Implemented CSV download from Devices table.</li>'
'<li>Corrected daily/monthly traffic counting to be able to handle big numbers.</li>'
'<li>Webtunnels (and SSH tunnels) now run on subdomain instead of sub-url.</li>'
'<li>Added SSHWifty tool being used as web SSH gateway (replaced WebSSH).</li>'
'<li>Added Reboot button into Devices table actions to schedule a reboot for a particular device.</li>'
'<li>List of triggered devices can now be accessed directly from alert definition table.</li>'
'<li>Improvements in UI - horizontal scrolling, ordering fix</li>'
'<li>If self-signed certificate is created (distributed to devices) it now contains CA certificate as well.</li>'
'<li>Updated Symfony.</li>'
'<li>Incorporated all fixes from stable support releases 1.0.1 - 1.0.4</li>'
'<li></li>'
'</ul><h6>Agents:</h6><ul>'
'<li>Support for CS-Tech devices (enhanced Advatech agent to cover both Advantech and CS-Tech devices)</li>'
'<li>Support firmware flash process on Teltonika devices (RUTOS).</li>'
'<li>Support firmware flash process on CS-Tech devices (CS-Tech Linux).</li>'
'<li>Moved all temporary data under /tmp directory for all agents and move persistent data for Advantech agent under /var/data/.</li>'
'<li>Teltonika: Dwarfguard agent installation survives firmware flash now (but is no longer registered as installed package by the opkg manager).</li>'
'<li>Teltonika: Startup protection - when FW flash disables Dwarfguard agent startup, backup mechanism enables it again.</li>'
'<li>Support sending device model name to server when detected.</li>'
'<li>FW flash process (in general) made more rebust.</li>'
'<li>Agent now tries to use old DevID if server requests re-registeration.</li>'
'<li>Improved agent upgrade and agent upgrade debug.</li>'
'<li>Fixed running agent detection on very old Advantech ICR OS firmware versions.</li>'
'</ul>');

INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.9.0_RC');
INSERT INTO product_flags(id, version, description) values ('about_info', 1, 'Dwarfguard - Monitoring, Alerting, Management and Automation System

Build tag: v1.9.0_RC
Build date: 2026_02_28__20_02_40

Build components:
(mamas): v1.9.0_RC
(mamasbig): v1.9.0_RC
(mamasweb): v1.9.0_RC
(mamasnotify): v1.9.0_RC');

==> dwarfg_install_2.0.0.tgz: dwarfg_install/appdir/db_init_verdata.sql <==
INSERT INTO agents (name, dir_name, package_name, minimal_version, dev_type, show_in_shortcut, description) VALUES
('Advantech routers', 'agent_advantech', 'adwarfg_advantech.tgz', '6.2.0', 2, true, 'Supports V2, V2i, V3 and V4 running ConelOS/ICR OS'),
("Teltonika routers - monitoring+FW flash", 'agent_teltonika', 'adwarfg_teltonika.ipk', NULL, 4, true, 'Monitoring only functionality, server certificate check is disabled.'),
("OpenWRT - only monitoring", 'agent_owrt', 'adwarfg_owrt.ipk', NULL, 3, true, 'Needs installing openssh-client for tunnels on the OpenWRT system, otherwise monitoring-only. Server certificate check is disabled.'),
('GNU/Linux (generic)', 'agent_linux', 'adwarfg_linux.tgz', NULL, 1, true, 'Generic Linux agent with systemd/initd integration. Cmdline installation.'),
("Teltonika routers - cmdline, monitoring+FW flash", 'agent_teltonika', 'adwarfg_teltonika.tgz', NULL, 4, false, 'Cmdline install. Needs installing openssh-client for tunnels on the Teltonika system. Server certificate check is disabled.'),
("OpenWRT - cmdline, mon. only", 'agent_owrt', 'adwarfg_owrt.tgz', NULL, 3, false, 'Cmdline install. Needs installing openssh-client for tunnels on the OpenWRT system. Server certificate check is disabled.'),
("AAD - automated agent deployment tool", 'aad', 'push_agent.py', NULL, 1, false, 'A command-line level Python tool to automate mass device installation. See documentation before experimenting.');

INSERT INTO agent_device_type_map (agent_id, device_type_id) VALUES (1, 2), (2, 1), (3, 3), (4, 4), (1, 5);

INSERT INTO agent_versions (dev_type, version_major, version_minor, version_patchlevel, actual) VALUES
(1, 2, 0, 0, true),
(2, 2, 0, 0, true),
(3, 2, 0, 0, true),
(4, 2, 0, 0, true);

INSERT INTO product_versions (id, actual, version_major, version_minor, version_patchlevel, version_string, major, beta, notification, force_display, release_date, description) values 
(1, true, 2, 0, 0, 'Keeper', false, true, true, true, NOW(),
'<h5>Release notes</h5>'
'<h6>Server:</h6><ul>'
'<li>Support for manual upload of firmware files by user + logging for this action.</li>'
'<li>Support firmware management for Teltonika devices (running RUTOS).</li>'
'<li>Customizable and centrally managed configuration profiles for Advantech routers.</li>'
'<li>Initial support for CS-Tech devices (includes firmware management for CS-Tech Linux).</li>'
'<li>Introduced SNMP Gateway to allow monitoring of SNMP devices (aimed at Advantech v1 routers but concept works for any SNMP device).</li>'
'<li>Implemented SSH tunnels via web gateway and proxy.</li>'
'<li>Customizable culumn names for Note1 .. Note3 columns (for administrator via commandline).</li>'
'<li>Support model name (device model) and added it as optional column on the Devices table allowing filtering+sorting based on that.</li>'
'<li>Improved Dwarfguard command-line integaration:</li>'
'<ul><li>Implemented non-interactive mode so that the commands could be used in scripting.</li>'
'<li>Added dwarfg_user command allowing server admin to add new UI users.</li>'
'<li>Added dwarfg_home and dwarfg_servdata commands to enter the deployment base directory/runtime data directory or just show the location when running non-interactively.</li>'
'<li>Added dwarfg_pyvenv command to enter the deployment base directory/show the location.</li></ul>'
'<li>Header line and detail/actions columns in the Devices table are now anchored.</li>'
'<li>Added SignalQuality as an optional column for the Devices table.</li>'
'<li>Added Note1,2,3 fields to the Device details.</li>'
'<li>Implemented CSV download from Devices table.</li>'
'<li>Corrected daily/monthly traffic counting to be able to handle big numbers.</li>'
'<li>Webtunnels (and SSH tunnels) now run on subdomain instead of sub-url.</li>'
'<li>Added SSHWifty tool being used as web SSH gateway (replaced WebSSH).</li>'
'<li>Added Reboot button into Devices table actions to schedule a reboot for a particular device.</li>'
'<li>List of triggered devices can now be accessed directly from alert definition table.</li>'
'<li>Improvements in UI - horizontal scrolling, ordering fix</li>'
'<li>If self-signed certificate is created (distributed to devices) it now contains CA certificate as well.</li>'
'<li>Updated Symfony.</li>'
'<li>Incorporated all fixes from stable support releases 1.0.1 - 1.0.4</li>'
'<li></li>'
'</ul><h6>Agents:</h6><ul>'
'<li>Support for CS-Tech devices (enhanced Advatech agent to cover both Advantech and CS-Tech devices)</li>'
'<li>Support firmware flash process on Teltonika devices (RUTOS).</li>'
'<li>Support firmware flash process on CS-Tech devices (CS-Tech Linux).</li>'
'<li>Moved all temporary data under /tmp directory for all agents and move persistent data for Advantech agent under /var/data/.</li>'
'<li>Teltonika: Dwarfguard agent installation survives firmware flash now (but is no longer registered as installed package by the opkg manager).</li>'
'<li>Teltonika: Startup protection - when FW flash disables Dwarfguard agent startup, backup mechanism enables it again.</li>'
'<li>Support sending device model name to server when detected.</li>'
'<li>FW flash process (in general) made more rebust.</li>'
'<li></li>'
'</ul>');

INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.4.3_BETA (+67)');
INSERT INTO product_flags(id, version, description) values ('about_info', 1, 'Dwarfguard - Monitoring, Alerting, Management and Automation System

Build tag: v1.4.3_BETA (+67)
Build date: 2026_02_20__19_29_28

Build components:
(mamas): v1.4.3_BETA (+32)
(mamasbig): v1.4.3_BETA (+4)
(mamasweb): v1.4.3_BETA (+31)
(mamasnotify): v1.4.3_BETA');
